plain_error_text

Function plain_error_text 

pub fn plain_error_text(e: &str) -> String
An error string as a person reads it: TypeError: Invalid URL, with the internal code and field markers of plain_coded_error / plain_coded_error_with removed. An uncaught native error is printed from its string, and printed the wire format (\u{1}code:ERR_INVALID_URL…).