pub fn split_error_fields(msg: &str) -> (&str, Vec<(&str, &str)>)
Split a plain_coded_error_with message back into the message and its fields. A message with no field mark comes back whole with no fields.
plain_coded_error_with