Module member

Module member 

DEF_MEMBER member-kind tags.

Constants

GET
METHOD
SET
STATIC_FIELD
A static FIELD (static x = 1), which is a data property of the constructor rather than a method. Only distinguished from METHOD for a PRIVATE name, where the declaration must install the private element without tripping the brand check an ordinary write to #x gets — and where node’s brand-check message words a field differently from a method.