call

Function call 

pub fn call(name: &str, args: &[Value]) -> Option<Result<Value, String>>
Dispatch a resolved stdlib builtin (assert, or namespace.method). Returns None if name is not a stdlib builtin (the caller falls through to the core builtin table).