buffer_slice

Function buffer_slice 

pub fn buffer_slice(ab: &Value, args: &[Value]) -> Value
ArrayBuffer.prototype.slice(begin[, end]) — a COPY of the byte range, as a new buffer. Writes to it are not seen by views over the original.