DEF_MEMBER member-kind tags.
Constants
- GET
- METHOD
- SET
- STATIC_
FIELD - A static FIELD (
static x = 1), which is a data property of the constructor rather than a method. Only distinguished fromMETHODfor a PRIVATE name, where the declaration must install the private element without tripping the brand check an ordinary write to#xgets — and where node’s brand-check message words a field differently from a method.